==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-metrics/src/main/java/org/apache/hadoop/hbase/metrics/impl/CounterImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.metrics.impl;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.metrics.Counter;
import org.apache.hadoop.hbase.util.LongAdder;

/**
 * Custom implementation of {@link org.apache.hadoop.hbase.metrics.Counter} using LongAdder.
 */
@InterfaceAudience.Private
public class CounterImpl implements Counter {

  private final LongAdder counter;

  public CounterImpl() {
    this.counter = new LongAdder();
  }

  @Override
  public void increment() {
    this.counter.increment();
  }

  @Override
  public void increment(long n) {
    this.counter.add(n);
  }

  @Override
  public void decrement() {
    this.counter.decrement();
  }

  @Override
  public void decrement(long n) {
    this.counter.add(-n);
  }

  @Override
  public long getCount() {
    return this.counter.sum();
  }
}

==> hbase-2.4.17-src.tar.gz: hbase-2.4.17/hbase-metrics/src/main/java/org/apache/hadoop/hbase/metrics/impl/CounterImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.metrics.impl;

import java.util.concurrent.atomic.LongAdder;
import org.apache.hadoop.hbase.metrics.Counter;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Custom implementation of {@link org.apache.hadoop.hbase.metrics.Counter} using LongAdder.
 */
@InterfaceAudience.Private
public class CounterImpl implements Counter {

  private final LongAdder counter;

  public CounterImpl() {
    this.counter = new LongAdder();
  }

  @Override
  public void increment() {
    this.counter.increment();
  }

  @Override
  public void increment(long n) {
    this.counter.add(n);
  }

  @Override
  public void decrement() {
    this.counter.decrement();
  }

  @Override
  public void decrement(long n) {
    this.counter.add(-n);
  }

  @Override
  public long getCount() {
    return this.counter.sum();
  }
}
